@@ -12,6 +12,7 @@ $(function() {
 	var $actionsDialog    = $("#actions-dialog");
 	var $optionsDialog = $("#options-dialog");
 	var $perlDocDialog = $("#perl-doc-dialog");
+	var $replDialog = $("#repl-dialog");
 
 	$("#theme_selector").change(function() {
 		var $selectedTheme = $(":selected", this);
@@ -213,13 +214,12 @@ $(function() {
 
 	$(".actions-button").click(function() {
 		$actionsDialog.modal('show');
-		$("#action").val('');
-		$("#action").focus();
+		$("#action-name").val('').focus();
 		findAction();
 	});
 	
 	var findAction = function() {
-		var action = $("#action", $actionsDialog).val();
+		var action = $("#action-name", $actionsDialog).val();
 		$("#matched-actions", $actionsDialog).empty();
 		$("#ok-button", $actionsDialog).attr("disabled","disabled");
 		$.ajax({
@@ -232,6 +232,7 @@ $(function() {
 					var a = matches[i];
 					html += "<option id='" + a.id + "' "  + 
 						((i == 0) ? "selected" : "") + 
+						' help="' + a.help + '"' +
 						">" + 
 						a.name + 
 						"</option>";
@@ -240,6 +241,9 @@ $(function() {
 					$("#ok-button", $actionsDialog).removeAttr("disabled");
 				}
 				$("#matched-actions", $actionsDialog).html(html);
+				$("#matched-actions", $actionsDialog).change(function() {
+					$("#action-help-text", $actionsDialog).html($("#matched-actions :selected", $actionsDialog).attr("help") );
+				});
 			},
 			error:   function(jqXHR, textStatus, errorThrown) {
 				console.error("Error:\n" + textStatus + "\n" + errorThrown);
@@ -248,12 +252,21 @@ $(function() {
 	}
 
 	var findActionTimeoutId;
-	$("#action", $actionsDialog).on('input', function() {
+	$("#action-name", $actionsDialog).on('input', function() {
 		clearTimeout(findActionTimeoutId);
 		findActionTimeoutId = setTimeout(findAction, 250);
 	});
+	
+	$actionsDialog.keyup(function(e) {
+		if(e.keyCode == 13) {
+			$("#ok-button", $actionsDialog).click();
+			return true; 
+		} else {
+			return false;
+		}
+	});
 
-	$("#action", $actionsDialog).keyup(function(evt) {
+	$("#action-name", $actionsDialog).keyup(function(evt) {
 		var keyCode = evt.keyCode;
 		if(keyCode == 40) {
 			$("#matched-actions", $actionsDialog).focus();
@@ -335,6 +348,46 @@ $(function() {
 	});
 
 	
+	/* REPL - Read-Eval-Read-Loop action */
+	$(document).on('action-repl', function() {
+		$replDialog.modal('show');
+		$("#command", $replDialog).focus();
+	});
+
+	var evalCommand = function() {
+		$.ajax({
+			type:    "POST",
+			url:     "/repl-eval",
+			data:    { "command": $("#command").val() },
+			success: function(result) {
+				console.error(result);
+				var oldOutput = $("#output", $replDialog).val();
+				if(oldOutput != '') {
+					oldOutput += "\n";
+				}
+				if(result.err != '') {
+					//result.out += "\nError: " + result.err;
+				}
+				$("#output", $replDialog).val(oldOutput + result.out);
+				$("#command", $replDialog).val('');
+			},
+			error:   function(jqXHR, textStatus, errorThrown) {
+				console.error("Error!" + textStatus + ", " + errorThrown);
+			}
+		});
+
+	};
+	
+	$("#command", $replDialog).click(function() {
+		evalCommand();
+	});
+	
+	$("#eval-button", $replDialog).click(function() {
+		evalCommand();
+	});
+	
+	/* End of REPL - Read-Eval-Read-Loop action */
+	
 	$(document).on('action-perl-doc', function() {
 		$perlDocDialog.modal('show');
 	});
@@ -464,22 +517,22 @@ $(function() {
 			}
 		} else if(runtime == "perl") { 
 			// Perl
-			$.post('/run_perl', {"source": editor.getValue() }, function(result) {
+			$.post('/run-perl', {"source": editor.getValue() }, function(result) {
 				show_cmd_output(result);
 			});
 		} else if(runtime == "rakudo") {
 			// Rakudo Perl 6
-			$.post('/run_rakudo', {"source": editor.getValue() }, function(result) {
+			$.post('/run-rakudo', {"source": editor.getValue() }, function(result) {
 				show_cmd_output(result);
 			});
 		} else if(runtime == "parrot") {
 			// Rakudo Perl 6
-			$.post('/run_parrot', {"source": editor.getValue() }, function(result) {
+			$.post('/run-parrot', {"source": editor.getValue() }, function(result) {
 				show_cmd_output(result);
 			});
 		} else if(runtime == "niecza") {
 			// Niecza
-			$.post('/run_niecza', {"source": editor.getValue() }, function(result) {
+			$.post('/run-niecza', {"source": editor.getValue() }, function(result) {
 				show_cmd_output(result);
 			});
 		}
